@@ -1,10 +1,10 @@
-use crate::messagebox::MessageBox;
-use crate::window::{Window, WindowAttributes};
-use crate::windowclass::WindowClass;
-use crate::Event::*;
+use crate::event::*;
 use crate::image::Icon;
 use crate::manifest::WindowManifest;
-use crate::NativesAndMessaging::*;
+use crate::messagebox::MessageBox;
+use crate::natives_and_messaging::*;
+use crate::window::{Window, WindowAttributes};
+use windows_sys::Win32::Foundation::PWSTR;
 
 pub struct DemoWindow {}
 
@@ -23,14 +23,20 @@ impl Window for DemoWindow {
             1280,
             750,
             500,
-            500
+            500,
         );
         attributes
     }
 
     fn manifest(&self) -> WindowManifest {
-        let manifest = WindowManifest::default();
-        manifest
+        unsafe {
+            let manifest = WindowManifest::new(
+                "window".to_string(),
+                "org.example.demo".to_string(),
+                Icon::new("./assets/icon.ico".to_string()),
+            );
+            manifest
+        }
     }
 
     fn exit(&self) {
