@@ -3,8 +3,8 @@ pub struct DialogEventHandler {
     event: DialogEventType,
 }
 
-#[cfg(linux)]
-struct DialogEventHandler {
+#[cfg(unix)]
+pub struct DialogEventHandler {
     event: DialogEventType,
 }
 
@@ -33,7 +33,7 @@ impl DialogEventHandler {
     }
 }
 
-#[cfg(linux)]
+#[cfg(unix)]
 impl DialogEventHandler {
     pub fn new() -> Self {
         Self { event: NONE }
