@@ -1,4 +1,4 @@
-use nxui::Demo::demowindow;
+use nxui::demo::demowindow;
 
 fn main() {
     println!("Hello World");
