@@ -1,19 +1,19 @@
 use windows_sys::Win32::Foundation::PSTR;
-use crate::image::Icon;
+use windows_sys::Win32::UI::WindowsAndMessaging::HICON;
 
 pub struct WindowManifest {
     pub class: PSTR,
     pub application_id: String,
-    icon: Icon
+    pub icon: HICON,
 }
 
 impl WindowManifest {
-    pub fn new(classname: String, application_id: String,icon: Icon) -> Self {
+    pub fn new(classname: String, application_id: String, icon: HICON) -> Self {
         let class: PSTR = classname.as_ptr() as _;
         Self {
             class,
             application_id,
-            icon
+            icon,
         }
     }
 }
@@ -24,7 +24,7 @@ impl Default for WindowManifest {
         Self {
             class,
             application_id: "org.example.demo".to_string(),
-            icon: Icon {}
+            icon: HICON::default(),
         }
     }
-}
\ No newline at end of file
+}
