@@ -1,16 +1,14 @@
-use crate::windowclass::WindowClass;
+use crate::manifest::WindowManifest;
 #[cfg(unix)]
 use gtk::gdk::WindowTypeHint;
 #[cfg(unix)]
 use gtk::prelude::*;
 #[cfg(unix)]
 use gtk::*;
-use std::borrow::Borrow;
 use windows_sys::{
     Win32::Foundation::*, Win32::Graphics::Gdi::ValidateRect,
     Win32::System::LibraryLoader::GetModuleHandleA, Win32::UI::WindowsAndMessaging::*,
 };
-use crate::manifest::WindowManifest;
 
 #[cfg(windows)]
 #[derive(Clone)]
@@ -140,7 +138,7 @@ pub trait Window {
     fn ui(&self) {
         println!("UI Phase")
     }
-    fn run(&self, attributes: WindowAttributes,manifest: WindowManifest) {
+    fn run(&self, attributes: WindowAttributes, manifest: WindowManifest) {
         println!("Run Phase");
         let window: HWND;
         extern "system" fn wndproc(
@@ -184,7 +182,7 @@ pub trait Window {
             let atom = RegisterClassA(&wc);
             debug_assert!(atom != 0);
 
-            CreateWindowExA(
+            let win = CreateWindowExA(
                 0,
                 manifest.class,
                 attributes.title.as_ptr() as _,
@@ -198,6 +196,12 @@ pub trait Window {
                 instance,
                 std::ptr::null_mut(),
             );
+            SendMessageA(
+                win,
+                WM_SETICON,
+                WPARAM::default(),
+                LPARAM::from(manifest.icon),
+            );
 
             let mut message = std::mem::zeroed();
 
